$NetBSD: patch-aj,v 1.1.1.1 2004/01/04 21:39:51 rh Exp $

--- addressbook/backend/pas/pas-backend-file.c.orig	Sun Jun 16 08:54:02 2002
+++ addressbook/backend/pas/pas-backend-file.c
@@ -21,9 +21,9 @@
 #include <e-util/e-db3-utils.h>
 
 #if DB_VERSION_MAJOR != 3 || \
-    DB_VERSION_MINOR != 1 || \
-    DB_VERSION_PATCH != 17
-#error Including wrong DB3.  Need libdb 3.1.17.
+    DB_VERSION_MINOR != 3 || \
+    DB_VERSION_PATCH != 11
+#error Including wrong DB3.  Need libdb 3.3.11.
 #endif
 
 #include <gtk/gtksignal.h>
@@ -1244,9 +1244,9 @@
 
 	db_version (&major, &minor, &patch);
 
-	if (major != 3 ||
-	    minor != 1 ||
-	    patch != 17) {
+	if (major != DB_VERSION_MAJOR ||
+	    minor != DB_VERSION_MINOR ||
+	    patch != DB_VERSION_PATCH) {
 		g_warning ("Wrong version of libdb.");
 		return GNOME_Evolution_Addressbook_BookListener_OtherError;
 	}
